@@ -1,21 +1,3 @@
-/*
- * Copyright (C) 2009 Wayne Meissner
- *
- * This file is part of jffi.
- *
- * This code is free software: you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License version 3 only, as
- * published by the Free Software Foundation.
- *
- * This code is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
- * version 3 for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with this work.  If not, see <http://www.gnu.org/licenses/>.
- */
-
 
 package com.kenai.jaffl.provider.jffi;
 
@@ -60,7 +42,9 @@ import static com.kenai.jaffl.provider.jffi.AsmUtil.*;
 
 public class AsmLibraryLoader extends LibraryLoader implements Opcodes {
     public final static boolean DEBUG = false || Boolean.getBoolean("jaffl.compile.dump");
-    private static final LibraryLoader INSTANCE = new AsmLibraryLoader();
+    private static final class SingletonHolder {
+        static final LibraryLoader INSTANCE = new AsmLibraryLoader();
+    }
     private static final boolean FAST_NUMERIC_AVAILABLE = isFastNumericAvailable();
     private static final boolean FAST_LONG_AVAILABLE = isFastLongAvailable();
     private final AtomicLong nextClassID = new AtomicLong(0);
@@ -68,7 +52,7 @@ public class AsmLibraryLoader extends LibraryLoader implements Opcodes {
     private final AtomicLong nextMethodID = new AtomicLong(0);
 
     static final LibraryLoader getInstance() {
-        return INSTANCE;
+        return SingletonHolder.INSTANCE;
     }
 
     boolean isInterfaceSupported(Class interfaceClass, Map<LibraryOption, ?> options) {
@@ -152,7 +136,7 @@ public class AsmLibraryLoader extends LibraryLoader implements Opcodes {
         ToNativeConverter[][] parameterConverters = new ToNativeConverter[methods.length][0];
         
         FunctionMapper functionMapper = libraryOptions.containsKey(LibraryOption.FunctionMapper)
-                ? (FunctionMapper) libraryOptions.get(LibraryOption.FunctionMapper) : IdentityFunctionMapper.INSTANCE;
+                ? (FunctionMapper) libraryOptions.get(LibraryOption.FunctionMapper) : IdentityFunctionMapper.getInstance();
 
         TypeMapper typeMapper = libraryOptions.containsKey(LibraryOption.TypeMapper)
                 ? (TypeMapper) libraryOptions.get(LibraryOption.TypeMapper) : NullTypeMapper.INSTANCE;
