@@ -1,5 +1,7 @@
 /*
- * Some of the design and code of this class is from the javolution project.
+ * This file is covered by the license described in the LICENSE file in the root of
+ * the project, however, it incorporates some code from the javolution project,
+ * and that copyright is reproduced here.
  *
  * Copyright (C) 2006 - Javolution (http://javolution.org/)
  * All rights reserved.
@@ -479,7 +481,7 @@ public abstract class Struct /*implements Marshallable */{
     /**
      * Base implementation of Member
      */
-    protected abstract class AbstractMember implements Member {
+    public abstract class AbstractMember implements Member {
         private final int offset;
         protected AbstractMember(int size) {
             this(size, size);
@@ -490,6 +492,14 @@ public abstract class Struct /*implements Marshallable */{
         protected AbstractMember(int size, int align) {
             this.offset = __info.addField(size, align);
         }
+
+        protected AbstractMember(Type type) {
+            this.offset = __info.addField(type.size() * 8, type.alignment() * 8);
+        }
+
+        protected AbstractMember(Type type, Offset offset) {
+            this.offset = __info.addField(type.size() * 8, type.alignment() * 8, offset);
+        }
         
         /**
          * Gets the <tt>MemoryIO</tt> used to read/write this <tt>Member</tt>.
@@ -517,6 +527,77 @@ public abstract class Struct /*implements Marshallable */{
         }
     }
     
+    /**
+     * Base class for Boolean fields
+     */
+    public abstract class AbstractBoolean extends AbstractMember {
+        public AbstractBoolean(Type type) {
+            super(type);
+        }
+
+        protected AbstractBoolean(Type type, Offset offset) {
+            super(type, offset);
+        }
+
+        /**
+         * Gets the value for this field.
+         *
+         * @return a boolean.
+         */
+        public abstract boolean get();
+
+        /**
+         * Sets the field to a new value.
+         *
+         * @param value The new value.
+         */
+        public abstract void set(boolean value);
+
+        /**
+         * Returns a string representation of this <code>Address</code>.
+         *
+         * @return a string representation of this <code>Address</code>.
+         */
+        @Override
+        public java.lang.String toString() {
+            return java.lang.Boolean.toString(get());
+        }
+    }
+
+    /**
+     * A normal C boolean - 1 byte in size
+     */
+    public final class Boolean extends AbstractBoolean {
+        public Boolean() {
+            super(Type.SCHAR);
+        }
+
+        public final boolean get() {
+            return (getMemoryIO().getByte(offset()) & 0x1) != 0;
+        }
+
+        public final void set(boolean value) {
+            getMemoryIO().putByte(offset(), (byte) (value ? 1 : 0));
+        }
+    }
+
+    /**
+     * A Windows BOOL - 4 bytes
+     */
+    public final class WBOOL extends AbstractBoolean {
+        public WBOOL() {
+            super(Type.SINT);
+        }
+
+        public final boolean get() {
+            return (getMemoryIO().getInt(offset()) & 0x1) != 0;
+        }
+
+        public final void set(boolean value) {
+            getMemoryIO().putInt(offset(), value ? 1 : 0);
+        }
+    }
+
     /**
      * Base class for all Number structure fields.
      */
@@ -1790,7 +1871,7 @@ public abstract class Struct /*implements Marshallable */{
      * members for more efficient struct construction.
      */
     public final class Padding extends AbstractMember {
-        Padding(Type type, int length) {
+        public Padding(Type type, int length) {
             super(type.size() * 8 * length, type.alignment() * 8);
         }
     }
